=======
Process
=======

Module: :mod:`jupyterlab_server.process`
========================================

.. automodule:: jupyterlab_server.process

.. currentmodule:: jupyterlab_server.process

.. autoclass:: Process
    :members:

.. autoclass:: WatchHelper
    :members:

.. autofunction:: which


Module: :mod:`jupyterlab_server.process_app`
============================================

.. automodule:: jupyterlab_server.process_app

.. currentmodule:: jupyterlab_server.process_app

:class:`ProcessApp`
-------------------

.. autoconfigurable:: ProcessApp
